@@ -59,7 +59,9 @@ from munch import Munch
 from packaging import version
 
 
-def search_actuator_functionalities(appliance: etree, actuator: str) -> etree | None:
+def search_actuator_functionalities(
+    appliance: etree.Element, actuator: str
+) -> etree.Element | None:
     """Helper-function for finding the relevant actuator xml-structure."""
     locator = f"./actuator_functionalities/{actuator}"
     if (search := appliance.find(locator)) is not None:
@@ -73,6 +75,7 @@ class SmileHelper(SmileCommon):
 
     def __init__(self) -> None:
         """Set the constructor for this class."""
+        super().__init__()
         self._endpoint: str
         self._elga: bool
         self._is_thermostat: bool
@@ -87,7 +90,16 @@ class SmileHelper(SmileCommon):
         self.smile_model: str
         self.smile_model_id: str | None
         self.smile_version: version.Version
-        SmileCommon.__init__(self)
+
+    @property
+    def gateway_id(self) -> str:
+        """Return the gateway-id."""
+        return self._gateway_id
+
+    @property
+    def item_count(self) -> int:
+        """Return the item-count."""
+        return self._count
 
     def _all_appliances(self) -> None:
         """Collect all appliances with relevant info.
@@ -195,6 +207,7 @@ class SmileHelper(SmileCommon):
                     other_entities = self.gw_entities
                     priority_entities = {entity_id: priority_entity}
                     self.gw_entities = {**priority_entities, **other_entities}
+                    break
 
     def _all_locations(self) -> None:
         """Collect all locations."""
@@ -212,7 +225,7 @@ class SmileHelper(SmileCommon):
                 f"./location[@id='{loc.loc_id}']"
             )
 
-    def _appliance_info_finder(self, appl: Munch, appliance: etree) -> Munch:
+    def _appliance_info_finder(self, appl: Munch, appliance: etree.Element) -> Munch:
         """Collect info for all appliances found."""
         match appl.pwclass:
             case "gateway":
@@ -230,7 +243,7 @@ class SmileHelper(SmileCommon):
                     appliance, "domestic_hot_water_mode_control_functionality"
                 )
                 # Skip orphaned heater_central (Core Issue #104433)
-                if appl.entity_id != self._heater_id:
+                if appl.entity_id != self.heater_id:
                     return Munch()
                 return appl
             case _ as s if s.endswith("_plug"):
@@ -250,9 +263,9 @@ class SmileHelper(SmileCommon):
                 appl.zigbee_mac = module_data["zigbee_mac_address"]
                 return appl
             case _:  # pragma: no cover
-                return appl
+                return Munch()
 
-    def _appl_gateway_info(self, appl: Munch, appliance: etree) -> Munch:
+    def _appl_gateway_info(self, appl: Munch, appliance: etree.Element) -> Munch:
         """Helper-function for _appliance_info_finder()."""
         self._gateway_id = appliance.attrib["id"]
         appl.firmware = str(self.smile_version)
@@ -285,7 +298,7 @@ class SmileHelper(SmileCommon):
         return appl
 
     def _get_appl_actuator_modes(
-        self, appliance: etree, actuator_type: str
+        self, appliance: etree.Element, actuator_type: str
     ) -> list[str]:
         """Get allowed modes for the given actuator type."""
         mode_list: list[str] = []
@@ -341,7 +354,7 @@ class SmileHelper(SmileCommon):
 
         # Get non-P1 data from APPLIANCES
         measurements = DEVICE_MEASUREMENTS
-        if self._is_thermostat and entity_id == self._heater_id:
+        if self._is_thermostat and entity_id == self.heater_id:
             measurements = HEATER_CENTRAL_MEASUREMENTS
             # Show the allowed dhw_modes (Loria only)
             if self._dhw_allowed_modes:
@@ -397,7 +410,7 @@ class SmileHelper(SmileCommon):
 
     def _appliance_measurements(
         self,
-        appliance: etree,
+        appliance: etree.Element,
         data: GwEntityData,
         measurements: dict[str, DATA | UOM],
     ) -> None:
@@ -429,7 +442,7 @@ class SmileHelper(SmileCommon):
         self._count = count_data_items(self._count, data)
 
     def _get_toggle_state(
-        self, xml: etree, toggle: str, name: ToggleNameType, data: GwEntityData
+        self, xml: etree.Element, toggle: str, name: ToggleNameType, data: GwEntityData
     ) -> None:
         """Helper-function for _get_measurement_data().
 
@@ -458,7 +471,7 @@ class SmileHelper(SmileCommon):
                 )
 
     def _get_actuator_functionalities(
-        self, xml: etree, entity: GwEntityData, data: GwEntityData
+        self, xml: etree.Element, entity: GwEntityData, data: GwEntityData
     ) -> None:
         """Get and process the actuator_functionalities details for an entity.
 
@@ -520,7 +533,7 @@ class SmileHelper(SmileCommon):
                 data[act_item] = temp_dict
 
     def _get_actuator_mode(
-        self, appliance: etree, entity_id: str, key: str
+        self, appliance: etree.Element, entity_id: str, key: str
     ) -> str | None:
         """Helper-function for _get_regulation_mode and _get_gateway_mode.
 
@@ -535,7 +548,7 @@ class SmileHelper(SmileCommon):
         return None
 
     def _get_regulation_mode(
-        self, appliance: etree, entity_id: str, data: GwEntityData
+        self, appliance: etree.Element, entity_id: str, data: GwEntityData
     ) -> None:
         """Helper-function for _get_measurement_data().
 
@@ -551,7 +564,7 @@ class SmileHelper(SmileCommon):
             self._cooling_enabled = mode == "cooling"
 
     def _get_gateway_mode(
-        self, appliance: etree, entity_id: str, data: GwEntityData
+        self, appliance: etree.Element, entity_id: str, data: GwEntityData
     ) -> None:
         """Helper-function for _get_measurement_data().
 
@@ -616,7 +629,7 @@ class SmileHelper(SmileCommon):
 
         Support added for Techneco Elga and Thercon Loria/Thermastage.
         """
-        if entity_id != self._heater_id:
+        if entity_id != self.heater_id:
             return
 
         if "elga_status_code" in data:
@@ -837,9 +850,7 @@ class SmileHelper(SmileCommon):
                 return presets  # pragma: no cover
 
         for rule_id in rule_ids:
-            directives: etree = self._domain_objects.find(
-                f'rule[@id="{rule_id}"]/directives'
-            )
+            directives = self._domain_objects.find(f'rule[@id="{rule_id}"]/directives')
             for directive in directives:
                 preset = directive.find("then").attrib
                 presets[directive.attrib["preset"]] = [
