@@ -23,6 +23,7 @@ from plugwise.constants import (
     NONE,
     OFF,
     P1_LEGACY_MEASUREMENTS,
+    PRIORITY_DEVICE_CLASSES,
     TEMP_CELSIUS,
     THERMOSTAT_CLASSES,
     UOM,
@@ -49,7 +50,7 @@ from munch import Munch
 from packaging.version import Version
 
 
-def etree_to_dict(element: etree) -> dict[str, str]:
+def etree_to_dict(element: etree.Element) -> dict[str, str]:
     """Helper-function translating xml Element to dict."""
     node: dict[str, str] = {}
     if element is not None:
@@ -63,18 +64,29 @@ class SmileLegacyHelper(SmileCommon):
 
     def __init__(self) -> None:
         """Set the constructor for this class."""
-        self._appliances: etree
+        super().__init__()
+        self._appliances: etree.Element
+        self._gateway_id: str = NONE
         self._is_thermostat: bool
         self._loc_data: dict[str, ThermoLoc]
-        self._locations: etree
-        self._modules: etree
+        self._locations: etree.Element
+        self._modules: etree.Element
         self._stretch_v2: bool
         self.gw_entities: dict[str, GwEntityData] = {}
         self.smile_mac_address: str | None
         self.smile_model: str
         self.smile_version: Version
         self.smile_zigbee_mac_address: str | None
-        SmileCommon.__init__(self)
+
+    @property
+    def gateway_id(self) -> str:
+        """Return the gateway-id."""
+        return self._gateway_id
+
+    @property
+    def item_count(self) -> int:
+        """Return the item-count."""
+        return self._count
 
     def _all_appliances(self) -> None:
         """Collect all appliances with relevant info."""
@@ -124,13 +136,13 @@ class SmileLegacyHelper(SmileCommon):
                 continue
 
             # Skip orphaned heater_central (Core Issue #104433)
-            if appl.pwclass == "heater_central" and appl.entity_id != self._heater_id:
+            if appl.pwclass == "heater_central" and appl.entity_id != self.heater_id:
                 continue  # pragma: no cover
 
             self._create_gw_entities(appl)
 
         # Place the gateway and optional heater_central devices as 1st and 2nd
-        for dev_class in ("heater_central", "gateway"):
+        for dev_class in PRIORITY_DEVICE_CLASSES:
             for entity_id, entity in dict(self.gw_entities).items():
                 if entity["dev_class"] == dev_class:
                     tmp_entity = entity
@@ -138,6 +150,7 @@ class SmileLegacyHelper(SmileCommon):
                     cleared_dict = self.gw_entities
                     add_to_front = {entity_id: tmp_entity}
                     self.gw_entities = {**add_to_front, **cleared_dict}
+                    break
 
     def _all_locations(self) -> None:
         """Collect all locations."""
@@ -171,11 +184,11 @@ class SmileLegacyHelper(SmileCommon):
 
         Use the home_location or FAKE_APPL as entity id.
         """
-        self.gateway_id = self._home_loc_id
+        self._gateway_id = self._home_loc_id
         if self.smile_type == "power":
-            self.gateway_id = FAKE_APPL
+            self._gateway_id = FAKE_APPL
 
-        self.gw_entities[self.gateway_id] = {"dev_class": "gateway"}
+        self.gw_entities[self._gateway_id] = {"dev_class": "gateway"}
         self._count += 1
         for key, value in {
             "firmware": str(self.smile_version),
@@ -188,7 +201,7 @@ class SmileLegacyHelper(SmileCommon):
         }.items():
             if value is not None:
                 gw_key = cast(ApplianceType, key)
-                self.gw_entities[self.gateway_id][gw_key] = value
+                self.gw_entities[self._gateway_id][gw_key] = value
                 self._count += 1
 
     def _appliance_info_finder(self, appliance: etree, appl: Munch) -> Munch:
@@ -266,7 +279,7 @@ class SmileLegacyHelper(SmileCommon):
             return data
 
         measurements = DEVICE_MEASUREMENTS
-        if self._is_thermostat and entity_id == self._heater_id:
+        if self._is_thermostat and entity_id == self.heater_id:
             measurements = HEATER_CENTRAL_MEASUREMENTS
 
         if (
@@ -280,7 +293,7 @@ class SmileLegacyHelper(SmileCommon):
 
         # Anna: the Smile outdoor_temperature is present in the Home location
         # For some Anna's LOCATIONS is empty, falling back to domain_objects!
-        if self._is_thermostat and entity_id == self.gateway_id:
+        if self._is_thermostat and entity_id == self._gateway_id:
             locator = f"./location[@id='{self._home_loc_id}']/logs/point_log[type='outdoor_temperature']/period/measurement"
             if (found := self._domain_objects.find(locator)) is not None:
                 value = format_measure(found.text, NONE)
@@ -316,7 +329,7 @@ class SmileLegacyHelper(SmileCommon):
 
     def _appliance_measurements(
         self,
-        appliance: etree,
+        appliance: etree.Element,
         data: GwEntityData,
         measurements: dict[str, DATA | UOM],
     ) -> None:
@@ -345,7 +358,7 @@ class SmileLegacyHelper(SmileCommon):
         self._count = count_data_items(self._count, data)
 
     def _get_actuator_functionalities(
-        self, xml: etree, entity: GwEntityData, data: GwEntityData
+        self, xml: etree.Element, entity: GwEntityData, data: GwEntityData
     ) -> None:
         """Helper-function for _get_measurement_data()."""
         for item in ACTIVE_ACTUATORS:
