@@ -167,8 +167,10 @@ class TestPlugwise:  # pylint: disable=attribute-defined-outside-init
                     "PUT", CORE_APPLIANCES_TAIL, self.smile_http_accept
                 )
             else:
+                app.router.add_route("POST", CORE_APPLIANCES_TAIL, self.smile_http_ok)
                 app.router.add_route("PUT", CORE_APPLIANCES_TAIL, self.smile_http_ok)
         else:
+            app.router.add_route("POST", CORE_APPLIANCES_TAIL, self.smile_timeout)
             app.router.add_route("PUT", CORE_LOCATIONS_TAIL, self.smile_timeout)
             app.router.add_route("PUT", CORE_RULES_TAIL, self.smile_timeout)
             app.router.add_route("PUT", CORE_APPLIANCES_TAIL, self.smile_timeout)
@@ -605,29 +607,30 @@ class TestPlugwise:  # pylint: disable=attribute-defined-outside-init
         with freeze_time(test_time):
             if initialize:
                 _LOGGER.info("Asserting testdata:")
+                data = await smile.async_update()
                 if smile.smile_legacy:
-                    await smile.full_xml_update()
-                    smile.get_all_gateway_entities()
-                    data = await smile.async_update()
                     assert smile._timeout == 30
                 else:
-                    data = await smile.async_update()
                     assert smile._timeout == 10
             else:
                 _LOGGER.info("Asserting updated testdata:")
                 data = await smile.async_update()
 
-        self.cooling_present = False
-        if "cooling_present" in data.gateway:
-            self.cooling_present = data.gateway["cooling_present"]
-        if "notifications" in data.gateway:
-            self.notifications = data.gateway["notifications"]
-        self.entity_items = data.gateway["item_count"]
+        _LOGGER.info("Gateway id = %s", smile.gateway_id)
+        _LOGGER.info("Heater id = %s", smile.heater_id)
+        _LOGGER.info("Hostname = %s", smile.smile_hostname)
+        _LOGGER.info("Entities list = %s", data)
+
+        self.cooling_present = smile.cooling_present
+        self.notifications = None
+        if "notifications" in data[smile.gateway_id]:
+            self.notifications = data[smile.gateway_id]["notifications"]
+        self.entity_items = smile.item_count
 
         self._cooling_active = False
         self._cooling_enabled = False
-        if "heater_id" in data.gateway:
-            heat_cooler = data.devices[data.gateway["heater_id"]]
+        if smile.heater_id != "None":
+            heat_cooler = data[smile.heater_id]
             if "binary_sensors" in heat_cooler:
                 if "cooling_enabled" in heat_cooler["binary_sensors"]:
                     self._cooling_enabled = heat_cooler["binary_sensors"][
@@ -638,27 +641,23 @@ class TestPlugwise:  # pylint: disable=attribute-defined-outside-init
                         "cooling_state"
                     ]
 
-        self._write_json("all_data", {"devices": data.devices, "gateway": data.gateway})
+        self._write_json("data", data)
 
         if "FIXTURES" in os.environ:
             _LOGGER.info("Skipping tests: Requested fixtures only")  # pragma: no cover
             return  # pragma: no cover
 
-        self.entity_list = list(data.devices.keys())
+        self.entity_list = list(data.keys())
         location_list = smile._loc_data
 
-        _LOGGER.info("Gateway id = %s", data.gateway["gateway_id"])
-        _LOGGER.info("Hostname = %s", smile.smile_hostname)
-        _LOGGER.info("Gateway data = %s", data.gateway)
-        _LOGGER.info("Entities list = %s", data.devices)
-        self.show_setup(location_list, data.devices)
+        self.show_setup(location_list, data)
 
         if skip_testing:
             return
 
         # Perform tests and asserts in two steps: devices and zones
         for header, data_dict in testdata.items():
-            test_and_assert(data_dict, data.devices, header)
+            test_and_assert(data_dict, data, header)
 
         # pragma warning restore S3776
 
